# python-botwinick-gis
GIS utilities

More documentation to come. Intended purpose is to support:
- automation of coordinate transformation to/from UTM or Lat/Lon
- helper functions for UTM to Lat/Lon and inverse
- helper functions for Lat/Lon DMS, arc-seconds, etc.
